
//  Copyright 1992, Massachusetts Institute of Technology. All Rights Reserved.

// --------------------------------------------------------------------
// Permission to use, copy, or modify this software and its documentation
// for educational and research purposes only and without fee is hereby
// granted, provided that this copyright notice appear on all copies and
// supporting documentation.  For any other uses of this software, in
// original or modified form, including but not limited to distribution
// in whole or in part, specific prior permission must be obtained from
// M.I.T. and the authors.  These programs shall not be used, rewritten,
// or adapted as the basis of a commercial software or hardware product
// without first obtaining appropriate licenses from M.I.T.  M.I.T. makes
// no representations about the suitability of this software for any
// purpose.  It is provided "as is" without express or implied warranty.

// ---------------------------------------------------------------------

//   Author: Andrew Sheaff
//   Date: 3/24/2000

//	Display an image under X
//	H H Atkins - AI Lab MIT 01/12/00
//	A Sheaff - AI Lab MIT 01/12/00


#ifndef __XDISPLAYIMAGE__HH
#define __XDISPLAYIMAGE__HH

//	"TV" screen interface
//	H H Atkins - AI Lab MIT 01/12/00
//	A Sheaff - AI Lab MIT 01/12/00

#include <X11/Xlib.h>
#include <X11/Xutil.h>
#include <sys/ipc.h>
#include <sys/shm.h>
#include <X11/extensions/XShm.h>

class XDisplayImage {
	protected:
		Display * Dpy;					// Display
		Visual * Pseudocolor_Visual;	// Visual
		XVisualInfo * VList;			// Visual List
		Window Root;					// Application "root" windows
		GC GrCon;						// Graphics Context
		Window Win;						// Win to display in
		Colormap CMap;					// Colormap
		XImage * Img;					// Image to display
		int Depth;						// Depth
		int Height;						// Height of image
		int Width;						// Width of display
		unsigned char * Buffer;			// Buffer 
		int Buf_Size;					// Size of buffer
		int Scrn;						// Screen
		unsigned int Screen_Depth;		// Depth of screen
		Status ShMemExt;				// Shared Memory Extensions
		XShmSegmentInfo XShMSI;			// Shared Memory Segment

		// Creates the window and shared memory
		int create_window(unsigned char * buffer, char * title);

	public:
		// Constructors - default will place a 640x480x4 window up.
		XDisplayImage(void);
		XDisplayImage(int width, int height, char * title);

		// Destructor
		~XDisplayImage(void);

		inline Display * display(void) {return (Dpy);}
		inline int depth(void) {return (Depth);}
		inline int width(void) {return (Width);}
		inline int height(void) {return (Height);}
		inline unsigned char * buffer(void) {return (Buffer);}

		void paint(const unsigned char * buf, const int width, const int height);
		void refresh(void);

		void title(char * t);
		void drawline(int x1, int y1, int x2, int y2);
		void setlinewidth(int w);
		void setcolor(unsigned long c);
		int drawtext(int x, int y, char * string);

		int waitforevent(void);
};

#endif
